from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean, File

Design_V0_1_0 = CommandToolBuilder(tool="design", base_command=["design"], inputs=[ToolInput(tag="in_dna", input_type=Boolean(optional=True), prefix="--dna", doc=InputDocumentation(doc="Specify that the sequence is DNA, and DNA parameters are to be used. The\ndefault is to use RNA parameters.")), ToolInput(tag="in_preselect", input_type=Boolean(optional=True), prefix="--preselect", doc=InputDocumentation(doc="Specify that use pre-selected sequence segments should be used. The default\nis that all nucleotides are chosen at random.")), ToolInput(tag="in_timer", input_type=Boolean(optional=True), prefix="--timer", doc=InputDocumentation(doc="Use a timer to measure the duration of the design process and print the\nelapsed time to standard output.")), ToolInput(tag="in_alphabet", input_type=Boolean(optional=True), prefix="--alphabet", doc=InputDocumentation(doc="Specify the name of a folding alphabet and associated nearest neighbor\nparameters. The alphabet is the prefix for the thermodynamic parameter\nfiles, e.g. 'rna' for RNA parameters or 'dna' for DNA parameters or a\ncustom extended/modified alphabet. The thermodynamic parameters need to\nreside in the at the location indicated by environment variable DATAPATH.\nThe default is 'rna' (i.e. use RNA parameters). This option overrides the\n--DNA flag.")), ToolInput(tag="in_error", input_type=Boolean(optional=True), prefix="--error", doc=InputDocumentation(doc="The maximum allowed ensemble defect per nucleotide.")), ToolInput(tag="in_maxdepth", input_type=Boolean(optional=True), prefix="--maxdepth", doc=InputDocumentation(doc="Max-depth: The maximum extent to which the structure will be sub-divided in\nthe binary decomposition. The default is 5.")), ToolInput(tag="in_max_leaf", input_type=Boolean(optional=True), prefix="--maxleaf", doc=InputDocumentation(doc="The maximum number of times a leaf can be re-optimized at random. The\ndefault is 3.")), ToolInput(tag="in_max_mutate", input_type=Boolean(optional=True), prefix="--maxmutate", doc=InputDocumentation(doc="The maximum number of times a nucleotide will be mutated during\ndefect-weighted reoptimization. The default is 4.")), ToolInput(tag="in_max_redesign", input_type=Boolean(optional=True), prefix="--maxredesign", doc=InputDocumentation(doc="The maximum number of redesigns per parent node. The default is 10.")), ToolInput(tag="in_output", input_type=File(optional=True), prefix="--output", doc=InputDocumentation(doc="Specify the output file. By default the resulting designed sequence is\nwritten to standard output only. This flag instructs the program to output\nthe structure (in ct format) to the specified file.")), ToolInput(tag="in_seed", input_type=Boolean(optional=True), prefix="--seed", doc=InputDocumentation(doc="Specify a random seed. This is required to get exactly reproducible\nresults. (The default is to use a seed based on the current system time).\n")), ToolInput(tag="in_ct_structure_file", input_type=File(), position=0, doc=InputDocumentation(doc=""))], outputs=[ToolOutput(tag="out_output", output_type=File(optional=True), selector=InputSelector(input_to_select="in_output", type_hint=File()), doc=OutputDocumentation(doc="Specify the output file. By default the resulting designed sequence is\nwritten to standard output only. This flag instructs the program to output\nthe structure (in ct format) to the specified file."))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Design_V0_1_0().translate("wdl", allow_empty_container=True)

